@@ -27,6 +27,7 @@ from woodwork.statistics_utils import (
     _get_mutual_information_dict,
     _get_valid_mi_columns,
     _get_value_counts,
+    _infer_temporal_frequencies,
 )
 from woodwork.table_schema import TableSchema
 from woodwork.type_sys.utils import _is_numeric_series, col_is_datetime
@@ -576,7 +577,7 @@ class WoodworkTableAccessor:
         cols_to_include = self._schema._filter_cols(include, exclude)
 
         if return_schema:
-            return self._schema._get_subset_schema(cols_to_include)
+            return self._schema.get_subset_schema(cols_to_include)
         return self._get_subset_df_with_schema(cols_to_include)
 
     @_check_table_schema
@@ -775,7 +776,7 @@ class WoodworkTableAccessor:
 
         assert all([col_name in self._schema.columns for col_name in cols_to_include])
 
-        new_schema = self._schema._get_subset_schema(cols_to_include)
+        new_schema = self._schema.get_subset_schema(cols_to_include)
         if inplace:
             cols_to_drop = [
                 col_name
@@ -1081,6 +1082,48 @@ class WoodworkTableAccessor:
         """
         return _get_value_counts(self._dataframe, ascending, top_n, dropna)
 
+    @_check_table_schema
+    def infer_temporal_frequencies(self, temporal_columns=None):
+        """Infers the observation frequency (daily, biweekly, yearly, etc) of each temporal column
+            in the DataFrame. Temporal columns are ones with the logical type Datetime or Timedelta.
+            Not supported for Dask and Koalas DataFrames.
+
+        Args:
+            temporal_columns (list[str], optional): Columns for which frequencies should be inferred. Must be columns
+                that are present in the DataFrame and are temporal in nature. Defaults to None. If not
+                specified, all temporal columns will have their frequencies inferred.
+
+        Returns:
+            (dict): A dictionary where each key is a temporal column from the DataFrame, and the
+                value is its observation frequency represented as a pandas offset alias string (D, M, Y, etc.)
+                or None if no uniform frequency was present in the data.
+
+        Note:
+            The pandas util ``pd.infer_freq``, which is used in this method, has the following behaviors:
+                - If even one row in a column does not follow the frequency seen in the remaining rows,
+                    no frequency will be inferred. Example of otherwise daily data that skips one day:
+                    ``['2011-01-03', '2011-01-04', '2011-01-05', '2011-01-07']``.
+                - If any NaNs are present in the data, no frequency will be inferred.
+                - Pandas will use the largest offset alias available to it, so ``W`` will be inferred for weekly data instead of ``7D``.
+                    The list of available offset aliases, which include aliases such as ``B`` for business day or ``N`` for nanosecond,
+                    can be found at https://pandas.pydata.org/pandas-docs/stable/user_guide/timeseries.html#offset-aliases
+                - Offset aliases can be combined to create something like ``2d1H``, which could also be expressed as '49H'.
+                    Pandas' frequency inference will return the lower common alias, ``49H``, in situations when it'd otherwise
+                    need to combine aliases.
+                - Offset strings can contain more information than just the offset alias. For example, a date range
+                    ``pd.date_range(start="2020-01-01", freq="w", periods=10)`` will be inferred to have frequency ``W-SUN``.
+                    That string is an offset alias with an anchoring suffix that indicates that the data is not only
+                    observed at a weekly frequency, but that all the dates are on Sundays. More anchored offsets
+                    can be seen here: https://pandas.pydata.org/pandas-docs/stable/user_guide/timeseries.html#anchored-offsets
+                - Some frequencies that can be defined for a ``pd.date_range`` cannot then be re-inferred by pandas' ``pd.infer_freq``.
+                    One example of this can be seen when using the business day offset alias ``B``
+                    ``pd.date_range(start="2020-01-01", freq="4b", periods=10)``, which is a valid ``freq``
+                    parameter when building the date range, but is not then inferrable.
+        """
+        return _infer_temporal_frequencies(
+            self._dataframe, temporal_columns=temporal_columns
+        )
+
 
 def _validate_accessor_params(
     dataframe, index, time_index, logical_types, schema, use_standard_tags
